---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2021-07-01;101
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20210706&codiceRedaz=21G00111&dataVigenza=20251104
dataGU: 20210706
codiceRedaz: 21G00111
dataVigenza: 20251104
---

# Conversione in legge, con modificazioni, del decreto-legge 6 maggio 2021, n. 59, recante misure urgenti relative al Fondo complementare al Piano nazionale di ripresa e resilienza e altre misure urgenti per gli investimenti. (21G00111)

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

1. Il decreto-legge 6 maggio 2021, n. 59, recante misure urgenti relative al Fondo complementare al Piano nazionale di ripresa e resilienza e altre misure urgenti per gli investimenti, e' convertito in legge con le modificazioni riportate in allegato alla presente legge.

2. La presente legge entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale.

